#!/usr/bin/python
# -*- coding: UTF-8 -*-

from pprint import pformat


class TableSchema(object):

    def __init__(self, tbl_name, columns, sort_columns=None):
        """
        Init the TableSchema instance

        :param str tbl_name: Table name
        :param list columns: The list of the columns
        :param list sort_columns: The list of the columns for sort
        """

        self._tbl_name = tbl_name
        self._columns = columns
        self._sort_columns = None

        if sort_columns is not None:
            assert isinstance(sort_columns, list)
            self._sort_columns = sort_columns

    @property
    def table_name(self):
        return self._tbl_name

    @property
    def columns(self):
        return self._columns

    @property
    def sort_columns(self):
        return self._sort_columns

    def to_dict(self):
        result = {
            'table_name': self._tbl_name,
            'columns': self._columns,
            'sort_columns': self._sort_columns
        }
        return result

    def to_str(self):
        return pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()


class Table(object):

    def __init__(self, name, db_name, table_list_info=None):
        self._name = name
        self._db_name = db_name
        self._table_list_info = table_list_info

    def to_dict(self):
        result = {
            'name': self.name,
            'database': self.database,
            'owner': self.owner,
            'table_type': self.table_type,
            'data_location': self.data_location,
            'data_type': self.data_type,
            'location': self.location,
            'partition_columns': self.partition_columns
        }
        return result

    def to_str(self):
        return pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    @property
    def name(self):
        return self._name

    @property
    def database(self):
        return self._db_name

    @property
    def owner(self):
        return self._table_list_info.owner

    @property
    def table_type(self):
        return self._table_list_info.table_type

    @property
    def data_location(self):
        return self._table_list_info.data_location

    @property
    def data_type(self):
        return self._table_list_info.data_type

    @property
    def location(self):
        return self._table_list_info.location

    @property
    def partition_columns(self):
        return self._table_list_info.partition_columns
